@@ -1,8 +1,8 @@
 from __future__ import unicode_literals
 
-__author__ = 'Filipe Ximenes'
-__email__ = 'filipeximenes@gmail.com'
-__version__ = '0.1.0'
+__author__ = 'Pavel Maksimov'
+__email__ = 'vur21@ya.ru'
+__version__ = '0.1.1'
 
 from .adapters import (
     generate_wrapper_from_adapter,
